================================
 Invenio-OAuth2Server v1.0.0a10
================================

Invenio-OAuth2Server v1.0.0a10 was released on October 3, 2016.

About
-----

Invenio module that implements OAuth 2 server.

*This is an experimental developer preview release.*

What's new
----------

- Refactores package.

Installation
------------

   $ pip install invenio-oauth2server==1.0.0a10

Documentation
-------------

   https://invenio-oauth2server.readthedocs.io/

Happy hacking and thanks for flying Invenio-OAuth2Server.

| Invenio Development Team
|   Email: info@inveniosoftware.org
|   IRC: #invenio on irc.freenode.net
|   Twitter: https://twitter.com/inveniosoftware
|   GitHub: https://github.com/inveniosoftware/invenio-oauth2server
|   URL: http://inveniosoftware.org
